# Tower Defence Server GDScript Client

An API for talking to the Tower Defence Server

This *Godot 4* addon was automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

− Servers:
    - [https://git.euph.dev/api/v1](https://git.euph.dev/api/v1)
    - [http://localhost:8080/api/v1](http://localhost:8080/api/v1)
- API version: 0.0.1
- Build package: org.openapitools.codegen.languages.GdscriptClientCodegen


## Requirements.

Godot `4.x`.


## Installation & Usage

Copy the files into the `addon` directory of your Godot project.

Then, enable the addon in your project settings.

You can now use it anywhere in your code:

```gdscript

# Customize configuration
var config := ApiConfig.new()
config.host = "localhost"
config.port = 8080
#config.tls_enabled = true
#config.trusted_chain = preload("res://my_cert_chain.crt")

# Instantiate the api
var api = AdminApi.new(config)
# You can also provide your own HTTPClient, to re-use it across apis.
#var api = AdminApi.new(config, client)


# Invoke an endpoint
api.admin_get_authenticated(
	# On Success
	func(response):  # response is ApiResponse
		prints("Success!", "admin_get_authenticated", response)
		assert(response.data is AdminAuthInfo)
		pass  # do things, make stuff
		,
	# On Error
	func(error):  # error is ApiError
		push_error(str(error))
		,
)

```


## Customization

You can [override the templates](https://openapi-generator.tech/docs/templating/).

> 1. Grab templates with `openapi-generator author template -g gdscript --library gdscript`
> 2. Hack around
> 3. Regenerate using `--template <dir>` to target your custom templates dir


## Documentation for API Endpoints

All URIs are relative to *https://git.euph.dev/api/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AdminApi* | [**admin_get_authenticated**](apis/AdminApi.md#admin_get_authenticated) | **GET** /admin/authenticated | 
*ServerApi* | [**player_login**](apis/ServerApi.md#player_login) | **POST** /player/login | 
*ServerApi* | [**player_register**](apis/ServerApi.md#player_register) | **POST** /player/register | 
*ServerApi* | [**server_get_healthcheck**](apis/ServerApi.md#server_get_healthcheck) | **GET** /server/health | 


## Documentation For Models

- [AdminAuthInfo](models/AdminAuthInfo.md)
- [PlayerLoginData](models/PlayerLoginData.md)
- [PlayerLoginSession](models/PlayerLoginSession.md)
- [PlayerRegistrationData](models/PlayerRegistrationData.md)
- [ServerHealth](models/ServerHealth.md)


## Documentation For Authorization

 Authentication schemes defined for the API:
## JWTAuth

- **Type**: Bearer authentication (JWT)



## Troubleshooting

### `TLS handshake error: -9984`

https://github.com/godotengine/godot/issues/59080#issuecomment-1065973210

